==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ResourceNavigationLinkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * ResourceNavigationLink resource.
 * @property id Resource ID.
 * @property link Link to the external resource
 * @property linkedResourceType Resource type of the linked resource.
 * @property name Name of the resource that is unique within a resource group. This name can be used to access the resource.
 */
public data class ResourceNavigationLinkArgs(
    public val id: Output<String>? = null,
    public val link: Output<String>? = null,
    public val linkedResourceType: Output<String>? = null,
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs =
        com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .link(link?.applyValue({ args0 -> args0 }))
            .linkedResourceType(linkedResourceType?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceNavigationLinkArgs].
 */
@PulumiTagMarker
public class ResourceNavigationLinkArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var link: Output<String>? = null

    private var linkedResourceType: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value Resource ID.
     */
    @JvmName("ncpobbyfdajwuckx")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Link to the external resource
     */
    @JvmName("jbcuhckvpfkkucug")
    public suspend fun link(`value`: Output<String>) {
        this.link = value
    }

    /**
     * @param value Resource type of the linked resource.
     */
    @JvmName("lqyrxiofkspemugw")
    public suspend fun linkedResourceType(`value`: Output<String>) {
        this.linkedResourceType = value
    }

    /**
     * @param value Name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("rguscfsmocijrknx")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("pbkbvsvogbxjumpc")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Link to the external resource
     */
    @JvmName("htfuvivwsyygbfpa")
    public suspend fun link(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.link = mapped
    }

    /**
     * @param value Resource type of the linked resource.
     */
    @JvmName("uurlxfbipkbbcjol")
    public suspend fun linkedResourceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedResourceType = mapped
    }

    /**
     * @param value Name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("mdnksauwwbjleclg")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ResourceNavigationLinkArgs = ResourceNavigationLinkArgs(
        id = id,
        link = link,
        linkedResourceType = linkedResourceType,
        name = name,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ResourceNavigationLinkArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * ResourceNavigationLink resource.
 * @property id Resource ID.
 * @property link Link to the external resource
 * @property linkedResourceType Resource type of the linked resource.
 * @property name Name of the resource that is unique within a resource group. This name can be used to access the resource.
 */
public data class ResourceNavigationLinkArgs(
    public val id: Output<String>? = null,
    public val link: Output<String>? = null,
    public val linkedResourceType: Output<String>? = null,
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs =
        com.pulumi.azurenative.network.inputs.ResourceNavigationLinkArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .link(link?.applyValue({ args0 -> args0 }))
            .linkedResourceType(linkedResourceType?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceNavigationLinkArgs].
 */
@PulumiTagMarker
public class ResourceNavigationLinkArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var link: Output<String>? = null

    private var linkedResourceType: Output<String>? = null

    private var name: Output<String>? = null

    /**
     * @param value Resource ID.
     */
    @JvmName("xcielhsmdedavmih")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Link to the external resource
     */
    @JvmName("gvpvjfyfadhmbvcp")
    public suspend fun link(`value`: Output<String>) {
        this.link = value
    }

    /**
     * @param value Resource type of the linked resource.
     */
    @JvmName("favnrtyfekcjmcoi")
    public suspend fun linkedResourceType(`value`: Output<String>) {
        this.linkedResourceType = value
    }

    /**
     * @param value Name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("brkcmqnnkhnxwpck")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("kkbagvbjixnectfv")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value Link to the external resource
     */
    @JvmName("eimgsenuyeouxrkl")
    public suspend fun link(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.link = mapped
    }

    /**
     * @param value Resource type of the linked resource.
     */
    @JvmName("nvwrsjjimdnlkkiy")
    public suspend fun linkedResourceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedResourceType = mapped
    }

    /**
     * @param value Name of the resource that is unique within a resource group. This name can be used to access the resource.
     */
    @JvmName("pxrvekjhspqmvmjo")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ResourceNavigationLinkArgs = ResourceNavigationLinkArgs(
        id = id,
        link = link,
        linkedResourceType = linkedResourceType,
        name = name,
    )
}
